;;; jsarticle.el - Special code for jsarticle style.

;; $Id: jsarticle.el,v 1.1 2005/02/11 19:02:08 oub Exp $

;;; Code:

(TeX-add-style-hook "jsarticle"
 (function (lambda ()
  (setq LaTeX-largest-level (LaTeX-section-level "section")))))

;;; jsarticle.el ends here
