;;; jsbook.el - Special code for jsbook style.

;; $Id: jsbook.el,v 1.1 2005/02/11 19:02:08 oub Exp $

;;; Code:

(TeX-add-style-hook "jsbook"
 (function (lambda () 
  (setq LaTeX-largest-level (LaTeX-section-level "chapter")))))

;;; jsbook.el ends here
